==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebOverlaySettingsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPositionStrategyDescriptionMetadata } from "./WebPositionStrategyDescriptionMetadata";
import { WebScrollStrategyDescriptionMetadata } from "./WebScrollStrategyDescriptionMetadata";
import { WebOverlaySettingsDescription } from "./WebOverlaySettingsDescription";
/**
 * @hidden
 */
var WebOverlaySettingsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebOverlaySettingsDescriptionMetadata, _super);
    function WebOverlaySettingsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebOverlaySettingsDescriptionMetadata.b = function (a) {
        if (WebOverlaySettingsDescriptionMetadata.a == null) {
            WebOverlaySettingsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebOverlaySettingsDescriptionMetadata.c(WebOverlaySettingsDescriptionMetadata.a);
        }
        if (a.j(WebOverlaySettingsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebOverlaySettingsDescriptionMetadata.a);
        WebPositionStrategyDescriptionMetadata.d(a);
        WebScrollStrategyDescriptionMetadata.d(a);
    };
    WebOverlaySettingsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:OverlaySettings");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Target", "Unknown");
        a.item("PositionStrategy", "ExportedType:WebPositionStrategy");
        a.item("ScrollStrategy", "ExportedType:WebScrollStrategy");
        a.item("Modal", "Boolean");
        a.item("CloseOnOutsideClick", "Boolean");
        a.item("CloseOnEscape", "Boolean");
    };
    WebOverlaySettingsDescriptionMetadata.d = function (a) {
        WebOverlaySettingsDescriptionMetadata.b(a);
        a.aa("WebOverlaySettings", function () { return new WebOverlaySettingsDescription(); });
        a.z("WebOverlaySettings", WebOverlaySettingsDescriptionMetadata.a);
    };
    WebOverlaySettingsDescriptionMetadata.$t = markType(WebOverlaySettingsDescriptionMetadata, 'WebOverlaySettingsDescriptionMetadata');
    WebOverlaySettingsDescriptionMetadata.a = null;
    return WebOverlaySettingsDescriptionMetadata;
}(Base));
export { WebOverlaySettingsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebOverlaySettingsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPositionStrategyDescriptionMetadata } from "./WebPositionStrategyDescriptionMetadata";
import { WebScrollStrategyDescriptionMetadata } from "./WebScrollStrategyDescriptionMetadata";
import { WebOverlaySettingsDescription } from "./WebOverlaySettingsDescription";
/**
 * @hidden
 */
var WebOverlaySettingsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebOverlaySettingsDescriptionMetadata, _super);
    function WebOverlaySettingsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebOverlaySettingsDescriptionMetadata.b = function (a) {
        if (WebOverlaySettingsDescriptionMetadata.a == null) {
            WebOverlaySettingsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebOverlaySettingsDescriptionMetadata.c(WebOverlaySettingsDescriptionMetadata.a);
        }
        if (a.k(WebOverlaySettingsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebOverlaySettingsDescriptionMetadata.a);
        WebPositionStrategyDescriptionMetadata.d(a);
        WebScrollStrategyDescriptionMetadata.d(a);
    };
    WebOverlaySettingsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:OverlaySettings");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Target", "Unknown");
        a.item("PositionStrategy", "ExportedType:WebPositionStrategy");
        a.item("ScrollStrategy", "ExportedType:WebScrollStrategy");
        a.item("Modal", "Boolean");
        a.item("CloseOnOutsideClick", "Boolean");
        a.item("CloseOnEscape", "Boolean");
    };
    WebOverlaySettingsDescriptionMetadata.d = function (a) {
        WebOverlaySettingsDescriptionMetadata.b(a);
        a.ac("WebOverlaySettings", function () { return new WebOverlaySettingsDescription(); });
        a.ab("WebOverlaySettings", WebOverlaySettingsDescriptionMetadata.a);
    };
    WebOverlaySettingsDescriptionMetadata.$t = markType(WebOverlaySettingsDescriptionMetadata, 'WebOverlaySettingsDescriptionMetadata');
    WebOverlaySettingsDescriptionMetadata.a = null;
    return WebOverlaySettingsDescriptionMetadata;
}(Base));
export { WebOverlaySettingsDescriptionMetadata };
